%% Fig. 1F
%% load
clear all
load behaviorData

%% calculate probabilities
% allmTrialY(:,K) = (trials,mice)
allCounts = sum([sum(allmTrialY);sum(allmNoLickY);sum(allmMissesY);sum(allmFAY)]);

for i = 1:15
    hitProbs(:,i) = allmTrialY(:,i)./allCounts(1,i);
    missProbs(:,i) = allmMissesY(:,i)./allCounts(1,i);
    noLickProbs(:,i) = allmNoLickY(:,i)./allCounts(1,i);
    falseAlarmProbs(:,i) = allmFAY(:,i)./allCounts(1,i);
end

%% jackknife

idx = nchoosek(1:15,14);
 
for i = 1:15
popHitR(:,i) = (sum(allmTrialY(:,idx(i,:)))./allCounts(1,idx(i,:)));
popMissR(:,i) = (sum([allmMissesY(:,idx(i,:)); allmNoLickY(:,idx(i,:))])./allCounts(1,idx(i,:)));
popFAR(:,i) = (sum(allmFAY(:,idx(i,:)))./allCounts(1,idx(i,:)));
end 

%% dprime per jackknife
for i = 1:15
dPrime(:,i) = norminv(popHitR(:,i)) - norminv(popFAR(:,i)); 
end

%% criterion per jackknife
for i = 1:15
criterion(:,i) = -((norminv(popHitR(:,i)) + norminv(popFAR(:,i))) ./2); 
end

 %% plots
 
figure; hold on; 
trialNums = 7;


plot(nanmean(popHitR(1:trialNums,:),2),'g','LineWidth',2)
plot(nanmean(popHitR(1:trialNums,:),2)'+nanstd(popHitR(1:trialNums,:)')./sqrt(15),'g')
plot(nanmean(popHitR(1:trialNums,:),2)'-nanstd(popHitR(1:trialNums,:)')./sqrt(15),'g')

plot(nanmean(popMissR(1:trialNums,:),2),'r','LineWidth',2)
plot(nanmean(popMissR(1:trialNums,:),2)'+nanstd(popMissR(1:trialNums,:)')./sqrt(15),'r')
plot(nanmean(popMissR(1:trialNums,:),2)'-nanstd(popMissR(1:trialNums,:)')./sqrt(15),'r')

plot(nanmean(popFAR(1:trialNums,:),2),'k','LineWidth',2)
plot(nanmean(popFAR(1:trialNums,:),2)'+nanstd(popFAR(1:trialNums,:)')./sqrt(15),'k')
plot(nanmean(popFAR(1:trialNums,:),2)'-nanstd(popFAR(1:trialNums,:)')./sqrt(15),'k')

axis square

xlabel('Trial Number')
ylabel('Rate')
set(gca,'xtick',1:trialNums)
xlim([0 trialNums+1])

%% dprime and criterion plot

y1 = nanmean(dPrime(1:trialNums,:),2) %matches above
y1Err = nanstd(dPrime(1:trialNums,:),1,2)
 
figure; 
hold on
subplot(121);
errorbar(y1,y1Err./sqrt(15),'b-')
line([1 trialNums],[0 0],'LineStyle', '--')
xlabel('Trial Number')
ylabel('Sensitivity (d'')')
set(gca,'xtick',1:trialNums)
xlim([0 trialNums+1])
ylim([-0.5 2.5])
set(gca,'box','off')
set(gca,'tickdir','out')
axis('square')

y2 = nanmean(criterion(1:trialNums,:),2) %matches above
y2Err = nanstd(criterion(1:trialNums,:),1,2)
 
subplot(122);
errorbar(y2,y2Err./sqrt(15),'b-')
line([1 trialNums],[0 0],'LineStyle', '--')
xlabel('Trial Number')
ylabel('Response criterion (c)')
set(gca,'xtick',1:trialNums)
xlim([0 trialNums+1])
ylim([-1 1])
set(gca,'box','off')
set(gca,'tickdir','out')
axis('square')

%% stats

[nanmedian(popHitR(1,:)), nanmedian(popHitR(5,:))]
p = signrank(popHitR(1,:),popHitR(5,:))

hr1 = [popHitR(1:3,:)]; hr2 = [popHitR(4:6,:)]
[nanmean(hr1(:)) nanstd(hr1(:))./sqrt(15)]
[nanmean(hr2(:)) nanstd(hr2(:))./sqrt(15)]


[nanmedian(popMissR(1,:)) nanmedian(popMissR(5,:))]
p = signrank(popMissR(1,:),popMissR(5,:))
mr1 = [popMissR(1:3,:)]; mr2 = [popMissR(4:6,:)]
[nanmean(mr1(:)) nanstd(mr1(:))./sqrt(15)]
[nanmean(mr2(:)) nanstd(mr2(:))./sqrt(15)]

[nanmedian(dPrime(1,:)) nanmedian(dPrime(5,:))]
d1 = [dPrime(1:3,:)]; d2 = [dPrime(4:6,:)]
[nanmean(d1(:)) nanstd(d1(:))./sqrt(15)]
[nanmean(d2(:)) nanstd(d2(:))./sqrt(15)]

[nanmedian(popFAR(1,:)) nanmedian(popFAR(5,:))]
f1 = [popFAR(1:3,:)]; f2 = [popFAR(4:6,:)]
[nanmean(f1(:)) nanstd(f1(:))./sqrt(15)]
[nanmean(f2(:)) nanstd(f2(:))./sqrt(15)]

p = ranksum(d1(:),d2(:))

[nanmedian(criterion(1,:)) nanmedian(criterion(5,:))]
p = signrank(criterion(1,:),criterion(5,:))
